@@ -12,6 +12,7 @@ sub new {
 }
 
 ### This returns a MatrixBitmap.pm of hexes of a PNG bitmap
+### (each hex a color, not a RGBA number on itself)
 sub loadPNGFile {
     my ($self, $pngfilename) = @_;
 
@@ -21,14 +22,16 @@ sub loadPNGFile {
     my $matrix = matrix->new($png->height, $png->width); ### see use at the top
     my $rows = ${$png->rows}; ### was a reference
 
-    for (my $j = 0; $j < $matrix->getRowsNumber; $j++) {
+    my $pngbppmultiplynumber = 4; ### R,G,B and A
+    
+    for (my $j = 0; $j < $matrix->getRowsNumber * $pngbppmultiplynumber; $j++) {
       my @rowofbytes = unpack('C*', $rows[$j]); ### https://stackoverflow.com/questions/13158976/split-binary-data-into-byte-array-in-perl
-      for (my $i = 0; $i < $matrix->getColumnsNumber; $i++) {
+      for (my $i = 0; $i < $matrix->getColumnsNumber * $pngbppmultiplynumber; $i++) {
 	$matrix->setAtIndex($j, $i, hex(@rowofbytes[$j][$i]));
       }
     }
 
-    ### NOTE : returns a class
+    ### NOTE : returns a class 
     return MatrixBitmap->new->setMatrix($matrix);
 }
 
