@@ -5,7 +5,7 @@ use parent 'OnePassBitmapAlgorithmComponent';
 sub new {
     my $self = shift;
 
-    $self = SUPER::OnePassBitmapAlgorithmComponent->new;
+    $self = SUPER::OnePassBitmapAlgorithmComponent->new(BagElement1);
 
     bless $self, $class;
 }
