@@ -28,15 +28,17 @@ sub getBag {
   return $self->{componentsbag};
 }
 
+### NOTE sets first element
 sub addToBag {
   my ($self, $bagel) = @_;
 
-  
+  $self->{componentsbag}->addBagElement1($bagel1);
+}
 
 sub pass {
     my ($self, $onepasssystem) = @_;
 
-    $onepasssystem->run($self);
+    return $onepasssystem->run($self);
 }
 
 1;
